@@ -41,6 +41,9 @@ FAILEDOPERATION_LANGUAGENOTSUPPORT = 'FailedOperation.LanguageNotSupport'
 # Not a Hong Kong identity card.
 FAILEDOPERATION_NOHKIDCARD = 'FailedOperation.NoHKIDCard'
 
+# Not a passport.
+FAILEDOPERATION_NOPASSPORT = 'FailedOperation.NoPassport'
+
 # OCR failed.
 FAILEDOPERATION_OCRFAILED = 'FailedOperation.OcrFailed'
 
