@@ -54,6 +54,34 @@ class SsmClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateSSHKeyPairSecret(self, request):
+        """This API is used to create a secret that hosts SSH keys.
+
+        :param request: Request instance for CreateSSHKeyPairSecret.
+        :type request: :class:`tencentcloud.ssm.v20190923.models.CreateSSHKeyPairSecretRequest`
+        :rtype: :class:`tencentcloud.ssm.v20190923.models.CreateSSHKeyPairSecretResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateSSHKeyPairSecret", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateSSHKeyPairSecretResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateSecret(self, request):
         """This API is used to create a KMS-encrypted Secret. You can create and store up to 1,000 Secrets in each region.
 
@@ -365,6 +393,34 @@ class SsmClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetSSHKeyPairValue(self, request):
+        """This API is used to obtain the plaintext value of the SSH key secret.
+
+        :param request: Request instance for GetSSHKeyPairValue.
+        :type request: :class:`tencentcloud.ssm.v20190923.models.GetSSHKeyPairValueRequest`
+        :rtype: :class:`tencentcloud.ssm.v20190923.models.GetSSHKeyPairValueResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GetSSHKeyPairValue", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetSSHKeyPairValueResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetSecretValue(self, request):
         """For user-defined credentials, this API is used to get the plaintext information of a credential by specifying the credential name and version.
         For Tencent Cloud service credentials such as MySQL credentials, this API is used to get the plaintext information of a previously rotated credential by specifying the credential name and historical version number. If you want to get the plaintext of the credential version currently in use, you need to specify the version number as `SSM_Current`.
